.. _zcml_directives:

ZCML Directives
===============

Comprehensive reference material for every ZCML directive provided by Pyramid
is available within this chapter.  The ZCML directive documentation is
organized alphabetically by directive name.

.. toctree::
   :maxdepth: 1

   zcml/aclauthorizationpolicy
   zcml/adapter
   zcml/authtktauthenticationpolicy
   zcml/asset
   zcml/configure
   zcml/default_permission
   zcml/forbidden
   zcml/include
   zcml/localenegotiator
   zcml/notfound
   zcml/remoteuserauthenticationpolicy
   zcml/renderer
   zcml/repozewho1authenticationpolicy
   zcml/route
   zcml/scan
   zcml/static
   zcml/subscriber
   zcml/translationdir
   zcml/utility
   zcml/view
